#######################################################
GWpy: A Python Package for Gravitational-Wave Astronomy
#######################################################

.. title:: GWpy Documentation

.. ifconfig:: 'dev' in release

    .. warning::

        You are viewing documentation for a development build of GWpy.
        This version may include unstable code, or breaking changes relative
        the most recent stable release.
        To view the documentation for the latest stable release of GWpy, please
        `click here <https://gwpy.readthedocs.io/en/stable/>`_.

**GWpy** is a collaboration-driven Python package
providing tools for studying data from ground-based gravitational-wave detectors.

GWpy provides a user-friendly, intuitive interface
to the common time-domain and frequency-domain data
produced by the `LIGO <http://www.ligo.org>`__ and `Virgo <http://www.ego-gw.it>`__ observatories
and their analyses,
with easy-to-follow tutorials at each step.

.. image:: https://img.shields.io/conda/vn/conda-forge/gwpy
    :target: https://anaconda.org/conda-forge/gwpy/
    :alt: GWpy Conda-forge version badge
.. image:: https://img.shields.io/pypi/v/gwpy
    :target: https://pypi.org/project/gwpy/
    :alt: GWpy PyPI version badge
.. image:: https://img.shields.io/pypi/l/gwpy.svg
    :target: https://choosealicense.com/licenses/gpl-3.0/
    :alt: GWpy license badge

----

Documentation
=============

.. grid:: 2
    :gutter: 2

    .. grid-item-card:: 🚀 Getting Started
        :link: getting-started
        :link-type: doc
        :text-align: center

        **New to GWpy?**
        Start here to install GWpy and learn the basics with a quick tutorial.

    .. grid-item-card:: 📖 User Guide
        :link: guide
        :link-type: doc
        :text-align: center

        **Solving a problem?**
        Practical guides for accomplishing specific tasks with GWpy.

    .. grid-item-card:: � API Reference
        :link: reference/index
        :link-type: doc
        :text-align: center

        **Looking up details?**
        Complete reference documentation for all GWpy classes and functions.

    .. grid-item-card:: 💡 Examples
        :link: examples/index
        :link-type: doc
        :text-align: center

        **Looking for inspiration?**
        Browse a collection of example notebooks showcasing GWpy in action.

    .. grid-item-card:: ℹ️ Project Info
        :link: about
        :link-type: doc
        :text-align: center

        **Learn more about GWpy**
        Information on the GWpy project.

.. toctree::
    :hidden:
    :maxdepth: 2

    Getting Started <getting-started>

.. toctree::
    :hidden:
    :maxdepth: 2

    User Guide <guide>

.. toctree::
    :hidden:
    :maxdepth: 2

    API Reference <reference/index>

.. toctree::
    :hidden:
    :maxdepth: 1

    Examples <examples/index>

.. toctree::
    :hidden:
    :maxdepth: 1

    Project Info <about>
